@@ -109,8 +109,9 @@ excluded_imports = {
     'argparse': set(('gettext', 'shutil')),
     'codecs': set(('encodings',)),
     'collections': set(('cPickle', 'pickle', 'doctest')),
-    'compileall': set(('concurrent',)),
+    'compileall': set(('concurrent', 'multiprocessing')),
     'copy': set(('reprlib',)),
+    'datetime': set(('_pydatetime',)),
     #'functools': set(('_dummy_thread',)),
     'hashlib': set(('logging', '_hashlib')),
     #'hashlib': set(('_hashlib', '_md5', '_sha', '_sha256','_sha512',)),
@@ -121,7 +122,7 @@ excluded_imports = {
     'os': set(('nt', 'ntpath', 'os2', 'os2emxpath', 'mac', 'macpath',
                'riscos', 'riscospath', 'riscosenviron')),
     'optparse': set(('gettext',)),
-    'pathlib': set(('urllib',)), # Windows only
+    'pathlib': set(('ntpath', 'urllib',)), # Windows only
     'pickle': set(('argparse', 'doctest', 'pprint')),
     'platform': set(('ctypes', 'plistlib', 'tempfile')),
     'reprlib': set(('_dummy_thread',)),
@@ -131,6 +132,7 @@ excluded_imports = {
     'subprocess': set(('dummy_threading',)),
     'sysconfig': set(('pprint','_osx_support', '_aix_support')),
     'tempfile': set(('_dummy_thread', 'shutil')),
+    'tokenize': set(('_tokenize',)),
     'functools': set(('typing',)),
     'platform': set(('distutils','plistlib')),
     'zipfile': set(('bz2','lzma')),
